![Logo](img/logo.png)

[![Documentation Status](https://img.shields.io/readthedocs/heatgraphy?color=00B796&logo=readthedocs&logoColor=white&style=flat-square)](https://heatgraphy.readthedocs.io/en/stable)
![pypi version](https://img.shields.io/pypi/v/heatgraphy?color=00B796&logo=python&logoColor=white&style=flat-square)


❗We are in beta, API may change and bugs expected

### Create x-layout visualization!

Quick start in the browser without a line of code!
[Open App](https://heatgraphy.streamlit.app)


### Installation

```shell
pip install heatgraphy
```

### Examples

| ![stacked bar](https://heatgraphy.readthedocs.io/en/latest/_images/sphx_glr_plot_stacked_bar_thumb.png) | ![heatmap](https://heatgraphy.readthedocs.io/en/latest/_images/sphx_glr_plot_pbmc3k_thumb.png) | ![oncoprint](https://heatgraphy.readthedocs.io/en/latest/_images/sphx_glr_plot_oncoprint_thumb.png) |
| :---:         |     :---:      |          :---: |
| **Stacked Bar** | **Heatmap** | **Oncoprint** |
